Crate tauri_plugin_valtio

tauri-plugin-valtio

Persistent Valtio stores for Tauri and React.

Features

  • Save your stores to disk.
  • Synchronize across multiple windows.
  • Debounce or throttle store updates.
  • Access the stores from both JavaScript and Rust.

Documentation

Check the documentation for more information on how to install and use the plugin.

Supported Tauri Version

This plugin requires Tauri 2.0 or later.

Structs

Builder
Builder for the Valtio plugin.
Store
A key-value store that can persist its state to disk.
StoreOptions
Options to configure the store behavior.
StoreState
Internal state of a store.
Valtio
The Valtio plugin.

Enums

Error
Json
Represents any valid JSON value.
SaveStrategy
The strategy to use when saving a store.

Traits

ManagerExt
Extension for the Manager trait providing access to the Valtio plugin.

Functions

init
Initializes the plugin with the default settings.
with_store
Calls a closure with a mutable reference to the store with the given id.

Type Aliases

BoxResult
A Result type with a boxed error.
OnLoadFn
Closure to be called when a store is loaded.
Result
A Result type with Error as the error variant.