pub struct Builder<R: Runtime> { /* private fields */ }Expand description
Builder for the Valtio plugin.
Implementations
Sourceimpl<R: Runtime> Builder<R>
impl<R: Runtime> Builder<R>
Sourcepub fn default_save_strategy(self, strategy: SaveStrategy) -> Self
pub fn default_save_strategy(self, strategy: SaveStrategy) -> Self
Sets the default save strategy to be used by the stores.
Sourcepub fn save_denylist(self, denylist: &[impl AsRef<str>]) -> Self
pub fn save_denylist(self, denylist: &[impl AsRef<str>]) -> Self
Sets a list of stores that should not be saved to disk.
Sourcepub fn sync_denylist(self, denylist: &[impl AsRef<str>]) -> Self
pub fn sync_denylist(self, denylist: &[impl AsRef<str>]) -> Self
Sets a list of stores that should not be synchronized across windows.