pub trait ManagerExt<R: Runtime>: Manager<R> {
// Provided methods
fn valtio(&self) -> State<'_, Valtio<R>> { ... }
fn with_store<F, T>(&self, id: impl AsRef<str>, f: F) -> Result<T>
where F: FnOnce(&mut Store<R>) -> T { ... }
}Expand description
Extension for the Manager trait providing access to the Valtio plugin.
Provided Methods
Sourcefn valtio(&self) -> State<'_, Valtio<R>>
fn valtio(&self) -> State<'_, Valtio<R>>
Returns a handle to the Valtio plugin.
Panics
Panics if the internal store collection is not in the resources table.
This likely indicates that the method was called before the plugin was properly initialized.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.