Crate tauri_plugin_valtio

tauri-plugin-valtio

Persistent Valtio stores for Tauri and React.

Features

  • Save your stores to disk.
  • Synchronize across multiple windows.
  • Debounce or throttle store updates.
  • Access the stores from both JavaScript and Rust.

Documentation

Check the documentation for more information on how to install and use the plugin.

Supported Tauri Version

This plugin requires Tauri 2.0 or later.

Structs

  • Builder for the Valtio plugin.
  • A key-value store that can persist its state to disk.
  • Options to configure the store behavior.
  • Internal state of a store.
  • The Valtio plugin.

Enums

Traits

Functions

  • Initializes the plugin with the default settings.
  • Calls a closure with a mutable reference to the store with the given id.

Type Aliases