Crate tauri_plugin_valtio

tauri-plugin-valtio

IMPORTANT: This is work in progress and SHOULD NOT be used before it reaches version 0.1.0. Expect breaking changes on every release before that. Tracking issue: ferreira-tb/tauri-store#75.

Persistent valtio stores for Tauri and React.

Features

  • Save your stores to disk.
  • Synchronize across multiple windows.
  • Debounce or throttle store updates.
  • Access the stores from both JavaScript and Rust.

Documentation

Check the documentation for more information on how to install and use the plugin.

Supported Tauri Version

This plugin requires Tauri 2.0 or later.

Structs

Enums

Traits

Functions

  • Initializes the plugin with the default settings.
  • Calls a closure with a mutable reference to the store with the given id.

Type Aliases