tauri_plugin_valtio

Trait ManagerExt

pub trait ManagerExt<R: Runtime>: Manager<R> {
    // Provided method
    fn valtio(&self) -> State<'_, Valtio<R>> { ... }
}
Extension for the Manager trait providing access to the Valtio plugin.

Provided Methods

fn valtio(&self) -> State<'_, Valtio<R>>

Returns a handle to the Valtio plugin.

Panics

Panics if the internal store collection is not in the resources table.

This likely indicates that the method was called before the plugin was properly initialized.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl<R: Runtime> ManagerExt<R> for AppHandle<R>

Source

impl<R: Runtime> ManagerExt<R> for WebviewWindow<R>

Source

impl<R: Runtime> ManagerExt<R> for Window<R>

Implementors